@@ -42,70 +42,45 @@
 
 namespace PDepend\DependencyInjection;
 
-use PDepend\Util\FileUtil;
-use PDepend\Util\Workarounds;
+use Exception;
+use ReflectionMethod;
+use Symfony\Component\Config\Definition\Builder\TreeBuilder;
 use Symfony\Component\Config\Definition\ConfigurationInterface;
-use Symfony\Component\Config\Definition\Builder\ArrayNodeDefinition;
-use Symfony\Component\Config\Definition\Builder\NodeBuilder;
+
+// <AbstractConfiguration>
+// @codeCoverageIgnoreStart
+if (!class_exists('PDepend\\DependencyInjection\\AbstractConfiguration')) {
+    $typingMode = 'weak';
+
+    try {
+        $method = new ReflectionMethod(
+            'Symfony\\Component\\Config\\Definition\\ConfigurationInterface',
+            'getConfigTreeBuilder'
+        );
+
+        if (method_exists($method, 'hasReturnType') && $method->hasReturnType()) {
+            $typingMode = 'strong';
+        }
+    } catch (Exception $exception) {
+        // keep "weak"
+    }
+
+    require_once __DIR__ . '/../../Lazy/PDepend/DependencyInjection/Configuration.' . $typingMode . '.php';
+}
+// @codeCoverageIgnoreEnd
+// </AbstractConfiguration>
 
 /**
- * This is the class that validates and merges configuration
- *
- * @copyright 2008-2017 Manuel Pichler. All rights reserved.
- * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @see ConfigurationInterface
+ * @see TreeBuilder
  */
-class Configuration implements ConfigurationInterface
+class Configuration extends AbstractConfiguration
 {
-    const DEFAULT_TTL = 2592000; //30 days
-
-    /**
-     * @var array<Extension>
-     */
-    private $extensions = array();
-
     /**
      * @param array<Extension> $extensions
      */
     public function __construct(array $extensions)
     {
-        $this->extensions = $extensions;
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getConfigTreeBuilder()
-    {
-        $home = FileUtil::getUserHomeDirOrSysTempDir();
-        $workarounds = new Workarounds();
-
-        $defaultCacheDriver = ($workarounds->hasSerializeReferenceIssue()) ? 'memory' : 'file';
-
-        $treeBuilder = new TreeBuilder();
-        /** @var ArrayNodeDefinition */
-        $rootNode = $treeBuilder->getRootNode();
-
-        $nodes = $rootNode->children();
-
-        $cacheNode = $nodes->arrayNode('cache')->addDefaultsIfNotSet()->children();
-        $cacheNode->enumNode('driver')->defaultValue($defaultCacheDriver)->values(array('file', 'memory'));
-        $cacheNode->scalarNode('location')->info('This value is only used for the file cache.')->defaultValue($home . '/.pdepend');
-        $cacheNode->integerNode('ttl')->info('This value is only used for the file cache. Value in seconds.')->defaultValue(self::DEFAULT_TTL);
-
-        $imageConvertNode = $nodes->arrayNode('image_convert')->addDefaultsIfNotSet()->children();
-        $imageConvertNode->scalarNode('font_size')->defaultValue('11');
-        $imageConvertNode->scalarNode('font_family')->defaultValue('Arial');
-
-        $parserNode = $nodes->arrayNode('parser')->addDefaultsIfNotSet()->children();
-        $parserNode->integerNode('nesting')->defaultValue(65536);
-
-        $extensionsNode = $nodes->arrayNode('extensions')->addDefaultsIfNotSet()->children();
-
-        foreach ($this->extensions as $extension) {
-            $extensionNode = $extensionsNode->arrayNode($extension->getName());
-            $extension->getConfig($extensionNode);
-        }
-
-        return $treeBuilder->getTreeBuilder();
+        $this->treeBuilderFactory = new TreeBuilderFactory($extensions);
     }
 }
