@@ -114,15 +114,4 @@ class ASTArguments extends AbstractASTNode
 
         parent::addChild($node);
     }
-
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since 0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitArguments($this, $data);
-    }
 }
