@@ -99,17 +99,4 @@ class ASTArrayElement extends ASTExpression
     {
         return 6;
     }
-
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @param ASTVisitor $visitor The calling visitor instance.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitArrayElement($this, $data);
-    }
 }
