@@ -135,19 +135,6 @@ class ASTClosure extends AbstractASTNode implements ASTCallable
         $this->setMetadataBoolean(6, (boolean) $static);
     }
 
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @param ASTVisitor $visitor The calling visitor instance.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitClosure($this, $data);
-    }
-
     /**
      * Returns the total number of the used property bag.
      *
