@@ -66,14 +66,4 @@ use PDepend\Source\ASTVisitor\ASTVisitor;
  */
 class ASTCompoundVariable extends AbstractASTNode
 {
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since 0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitCompoundVariable($this, $data);
-    }
 }
