@@ -42,8 +42,6 @@
 
 namespace PDepend\Source\AST;
 
-use PDepend\Source\ASTVisitor\ASTVisitor;
-
 /**
  * This class represents a single constant declarator within a constant
  * definition.
@@ -81,6 +79,13 @@ use PDepend\Source\ASTVisitor\ASTVisitor;
  */
 class ASTConstantDeclarator extends AbstractASTNode
 {
+    /**
+     * The type of the constant if explicitly specified, <b>null</b> else.
+     *
+     * @var ASTType|null
+     */
+    protected $type = null;
+
     /**
      * The initial declaration value for this node or <b>null</b>.
      *
@@ -88,6 +93,26 @@ class ASTConstantDeclarator extends AbstractASTNode
      */
     protected $value = null;
 
+    /**
+     * Returns the explicitly specified type of the constant.
+     *
+     * @return ASTType|null
+     */
+    public function getType()
+    {
+        return $this->type;
+    }
+
+    /**
+     * Set the explicitly specified type of the constant.
+     *
+     * @return void
+     */
+    public function setType(ASTType $type = null)
+    {
+        $this->type = $type;
+    }
+
     /**
      * Returns the initial declaration value for this node.
      *
@@ -108,17 +133,6 @@ class ASTConstantDeclarator extends AbstractASTNode
         $this->value = $value;
     }
 
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitConstantDeclarator($this, $data);
-    }
-
     /**
      * Magic sleep method that returns an array with those property names that
      * should be cached for this node instance.
