@@ -137,18 +137,6 @@ class ASTConstantDefinition extends AbstractASTNode
         return (($this->getModifiers() & State::IS_PRIVATE) === State::IS_PRIVATE);
     }
 
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since 0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitConstantDefinition($this, $data);
-    }
-
-
     /**
      * Returns the total number of the used property bag.
      *
