@@ -141,16 +141,6 @@ class ASTFunction extends AbstractASTCallable
         return $this->namespaceName;
     }
 
-    /**
-     * ASTVisitor method for node tree traversal.
-     *
-     * @return void
-     */
-    public function accept(ASTVisitor $visitor)
-    {
-        $visitor->visitFunction($this);
-    }
-
     /**
      * The magic sleep method will be called by the PHP engine when this class
      * gets serialized. It returns an array with those properties that should be
