@@ -38,6 +38,7 @@
  *
  * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ *
  * @since 0.9.8
  */
 
@@ -50,6 +51,7 @@ use PDepend\Source\ASTVisitor\ASTVisitor;
  *
  * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
+ *
  * @since 2.9.0
  */
 class ASTNamedArgument extends AbstractASTNode
@@ -93,18 +95,4 @@ class ASTNamedArgument extends AbstractASTNode
     {
         return sprintf('%s: %s', $this->name, $this->getChild(0)->getImage());
     }
-
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @param ASTVisitor $visitor The calling visitor instance.
-     * @param mixed      $data
-     *
-     * @return mixed
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitNamedArgument($this, $data);
-    }
 }
