@@ -338,6 +338,8 @@ class ASTParameter extends AbstractASTArtifact
      * {@link ASTParameter::isDefaultValueAvailable()} to
      * detect a NULL-value.
      *
+     * @return mixed
+     *
      * @since  0.9.5
      */
     public function getDefaultValue()
@@ -347,16 +349,6 @@ class ASTParameter extends AbstractASTArtifact
         return $value === null ? null : $value->getValue();
     }
 
-    /**
-     * ASTVisitor method for node tree traversal.
-     *
-     * @return void
-     */
-    public function accept(ASTVisitor $visitor)
-    {
-        $visitor->visitParameter($this);
-    }
-
     /**
      * Returns the wrapped formal parameter instance.
      *
@@ -416,6 +408,11 @@ class ASTParameter extends AbstractASTArtifact
         );
     }
 
+    /**
+     * @param ASTNode $node
+     *
+     * @return bool
+     */
     private function isTypeAllowingNull($node)
     {
         if ($node instanceof ASTUnionType) {
