@@ -103,17 +103,6 @@ final class ASTParentReference extends ASTClassOrInterfaceReference
         return $this->reference->getType();
     }
 
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitParentReference($this, $data);
-    }
-
     /**
      * The magic sleep method will be called by PHP's runtime environment right
      * before an instance of this class gets serialized. It should return an
