@@ -136,15 +136,4 @@ class ASTSelfReference extends ASTClassOrInterfaceReference
 
         return array_merge(array('qualifiedName'), parent::__sleep());
     }
-
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitSelfReference($this, $data);
-    }
 }
