@@ -68,16 +68,4 @@ use PDepend\Source\ASTVisitor\ASTVisitor;
  */
 class ASTString extends AbstractASTNode
 {
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @param ASTVisitor $visitor The calling visitor instance.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitString($this, $data);
-    }
 }
