@@ -68,15 +68,4 @@ class ASTTraitReference extends ASTClassOrInterfaceReference
         }
         return $this->typeInstance;
     }
-
-    /**
-     * Accept method of the visitor design pattern. This method will be called
-     * by a visitor during tree traversal.
-     *
-     * @since  0.9.12
-     */
-    public function accept(ASTVisitor $visitor, $data = null)
-    {
-        return $visitor->visitTraitReference($this, $data);
-    }
 }
