@@ -221,10 +221,7 @@ abstract class PHPParserVersion56 extends PHPParserVersion55
                     $expressions[] = $expr;
                     break;
                 default:
-                    throw new UnexpectedTokenException(
-                        $this->tokenizer->next(),
-                        $this->tokenizer->getSourceFile()
-                    );
+                    throw $this->getUnexpectedNextTokenException();
             }
         }
 
@@ -370,6 +367,9 @@ abstract class PHPParserVersion56 extends PHPParserVersion55
         return $arguments;
     }
 
+    /**
+     * @return ASTNode|null
+     */
     protected function parseArgumentExpression()
     {
         return $this->parseOptionalExpression();
