@@ -58,6 +58,7 @@ use PDepend\Source\AST\ASTUnionType;
 use PDepend\Source\AST\State;
 use PDepend\Source\Parser\ParserException;
 use PDepend\Source\Parser\UnexpectedTokenException;
+use PDepend\Source\Tokenizer\Token;
 use PDepend\Source\Tokenizer\Tokens;
 
 /**
@@ -209,7 +210,9 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
 
         if (isset($states[$token])) {
             $modifier |= $states[$token];
-            $this->tokenStack->add($this->tokenizer->next());
+            $next = $this->tokenizer->next();
+            assert($next instanceof Token);
+            $this->tokenStack->add($next);
         }
 
         return $modifier;
@@ -235,7 +238,9 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
     protected function parseConstantArgument(ASTConstant $constant, ASTArguments $arguments)
     {
         if ($this->tokenizer->peek() === Tokens::T_COLON) {
-            $this->tokenStack->add($this->tokenizer->next());
+            $token = $this->tokenizer->next();
+            assert($token instanceof Token);
+            $this->tokenStack->add($token);
 
             return $this->builder->buildAstNamedArgument(
                 $constant->getImage(),
@@ -290,11 +295,17 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
         return $function;
     }
 
+    /**
+     * @return ASTType
+     */
     protected function parseEndReturnTypeHint()
     {
         return $this->parseTypeHint();
     }
 
+    /**
+     * @return ASTType
+     */
     protected function parseSingleTypeHint()
     {
         $this->consumeComments();
@@ -314,11 +325,15 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
                 break;
             case Tokens::T_NULL:
                 $type = new ASTScalarType('null');
-                $this->tokenStack->add($this->tokenizer->next());
+                $token = $this->tokenizer->next();
+                assert($token instanceof Token);
+                $this->tokenStack->add($token);
                 break;
             case Tokens::T_FALSE:
                 $type = new ASTScalarType('false');
-                $this->tokenStack->add($this->tokenizer->next());
+                $token = $this->tokenizer->next();
+                assert($token instanceof Token);
+                $this->tokenStack->add($token);
                 break;
             default:
                 $type = parent::parseTypeHint();
@@ -340,7 +355,9 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
         $types = array($firstType);
 
         while ($this->tokenizer->peek() === Tokens::T_BITWISE_OR) {
-            $this->tokenStack->add($this->tokenizer->next());
+            $token = $this->tokenizer->next();
+            assert($token instanceof Token);
+            $this->tokenStack->add($token);
             $types[] = $this->parseSingleTypeHint();
         }
 
@@ -352,6 +369,11 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
         return $unionType;
     }
 
+    /**
+     * @param ASTType $type
+     *
+     * @return ASTType
+     */
     protected function parseTypeHintCombination($type)
     {
         if ($this->tokenizer->peek() === Tokens::T_BITWISE_OR) {
@@ -371,6 +393,9 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
         return $type instanceof ASTScalarType && ($type->isFalse() || $type->isNull());
     }
 
+    /**
+     * @return ASTType
+     */
     protected function parseTypeHint()
     {
         $this->consumeComments();
@@ -412,12 +437,17 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
     /**
      * use of trailing comma in formal parameters list is allowed since PHP 8.0
      * example function foo(string $bar, int $baz,)
+     *
+     * @return bool
      */
     protected function allowTrailingCommaInFormalParametersList()
     {
         return true;
     }
 
+    /**
+     * @return bool
+     */
     protected function isNextTokenObjectOperator()
     {
         return in_array($this->tokenizer->peek(), array(
@@ -442,10 +472,11 @@ abstract class PHPParserVersion80 extends PHPParserVersion74
                 Tokens::T_SEMICOLON,
                 Tokens::T_COMMA,
                 Tokens::T_COLON,
-                Tokens::T_PARENTHESIS_CLOSE
+                Tokens::T_PARENTHESIS_CLOSE,
+                Tokens::T_SQUARED_BRACKET_CLOSE
             ));
         }
 
-        $this->throwUnexpectedTokenException();
+        throw $this->getUnexpectedNextTokenException();
     }
 }
