@@ -892,6 +892,11 @@ interface Tokens
      */
     const T_NULLSAFE_OBJECT_OPERATOR = 387;
 
+    /**
+     * Marks an enum token.
+     */
+    const T_ENUM = 372;
+
     /**
      * Marks any content not between php tags.
      */
