@@ -42,6 +42,8 @@
 
 namespace PDepend;
 
+use PDepend\Metrics\Analyzer\CrapIndexAnalyzer;
+
 /**
  * Test cases for the {@link \PDepend\Application} class.
  *
@@ -58,21 +60,21 @@ class ApplicationTest extends AbstractTest
         $application = $this->createTestApplication();
         $runner = $application->getRunner();
 
-        $this->assertInstanceOf('PDepend\TextUI\Runner', $runner);
+        $this->assertInstanceOf('PDepend\\TextUI\\Runner', $runner);
     }
 
     public function testAnalyzerFactory()
     {
         $application = $this->createTestApplication();
 
-        $this->assertInstanceOf('PDepend\Metrics\AnalyzerFactory', $application->getAnalyzerFactory());
+        $this->assertInstanceOf('PDepend\\Metrics\\AnalyzerFactory', $application->getAnalyzerFactory());
     }
 
     public function testReportGeneratorFactory()
     {
         $application = $this->createTestApplication();
 
-        $this->assertInstanceOf('PDepend\Report\ReportGeneratorFactory', $application->getReportGeneratorFactory());
+        $this->assertInstanceOf('PDepend\\Report\\ReportGeneratorFactory', $application->getReportGeneratorFactory());
     }
 
     public function testBinCanReadInput()
@@ -107,7 +109,7 @@ class ApplicationTest extends AbstractTest
         $application = $this->createTestApplication();
         $config = $application->getConfiguration();
 
-        $this->assertInstanceOf('PDepend\Util\Configuration', $config);
+        $this->assertInstanceOf('PDepend\\Util\\Configuration', $config);
     }
 
     public function testGetEngine()
@@ -115,6 +117,28 @@ class ApplicationTest extends AbstractTest
         $application = $this->createTestApplication();
         $config = $application->getEngine();
 
-        $this->assertInstanceOf('PDepend\Engine', $config);
+        $this->assertInstanceOf('PDepend\\Engine', $config);
+    }
+
+    public function testGetAvailableLoggerOptions()
+    {
+        $application = $this->createTestApplication();
+        $options = $application->getAvailableLoggerOptions();
+
+        $this->assertSame(array(
+            'message' => 'Dummy logger for tests',
+            'value' => 'file',
+        ), $options['--dummy-logger']);
+    }
+
+    public function testGetAvailableAnalyzerOptions()
+    {
+        $application = $this->createTestApplication();
+        $options = $application->getAvailableAnalyzerOptions();
+
+        $this->assertSame(array(
+            'message' => "Clover style CodeCoverage report, as produced by PHPUnit's --coverage-clover option.",
+            'value' => 'file',
+        ), $options['--' . CrapIndexAnalyzer::REPORT_OPTION]);
     }
 }
