@@ -41,6 +41,9 @@
 namespace PDepend\Source\Language\PHP\Features\PHP80;
 
 use PDepend\AbstractTest;
+use PDepend\Source\Builder\Builder;
+use PDepend\Source\Tokenizer\Tokenizer;
+use PDepend\Util\Cache\CacheDriver;
 
 /**
  * @copyright 2008-2017 Manuel Pichler. All rights reserved.
@@ -61,4 +64,18 @@ abstract class PHPParserVersion80Test extends AbstractTest
     {
         return version_compare(PHP_VERSION, '8.0.0-dev', '<');
     }
+
+    /**
+     * @param \PDepend\Source\Tokenizer\Tokenizer $tokenizer
+     * @param \PDepend\Source\Builder\Builder $builder
+     * @param \PDepend\Util\Cache\CacheDriver $cache
+     * @return \PDepend\Source\Language\PHP\AbstractPHPParser
+     */
+    protected function createPHPParser(Tokenizer $tokenizer, Builder $builder, CacheDriver $cache)
+    {
+        return $this->getAbstractClassMock(
+            'PDepend\\Source\\Language\\PHP\\PHPParserVersion80',
+            array($tokenizer, $builder, $cache)
+        );
+    }
 }
