@@ -768,6 +768,14 @@ class PHPParserGenericTest extends AbstractTest
         $this->assertNotNull($method);
     }
 
+    /**
+     * @return void
+     */
+    public function testParserHandlesExtraParenthesisForIsset()
+    {
+        $this->assertEmpty($this->parseCodeResourceForTest());
+    }
+
     /**
      * Returns the first class or interface that could be found in the code under
      * test for the calling test case.
