@@ -208,7 +208,7 @@ class PHPTokenizerInternalTest extends AbstractTest
         while (is_object($token = $tokenizer->next())) {
             $actual[] = array($token->type, $token->startLine);
         }
-        
+
         $this->assertEquals($expected, $actual);
     }
 
@@ -451,6 +451,47 @@ class PHPTokenizerInternalTest extends AbstractTest
         $this->assertSame($expected, $actual);
     }
 
+    /**
+     * Tests the tokenizer support short-echo-tags with multiple variables separated by comas.
+     *
+     * @return void
+     */
+    public function testTokenizingShortTagsWithMultipleVariables()
+    {
+        if (PHP_VERSION < 5.4 && ! ini_get('short_open_tag')) {
+            $this->markTestSkipped('Must enable short_open_tag before PHP 5.4');
+        }
+
+        $tokenizer  = new PHPTokenizerInternal();
+        $tokenizer->setSourceFile($this->createCodeResourceUriForTest());
+
+        $expected = array(
+            array(Tokens::T_OPEN_TAG_WITH_ECHO, '<?=', 1, 1, 1, 3),
+            array(Tokens::T_VARIABLE, '$foo', 1, 1, 4, 7),
+            array(Tokens::T_COMMA, ',', 1, 1, 8, 8),
+            array(Tokens::T_VARIABLE, '$bar', 1, 1, 9, 12),
+            array(Tokens::T_CLOSE_TAG, '?>', 1, 1, 13, 14),
+        );
+
+        $actual = array();
+        while (is_object($token = $tokenizer->next())) {
+            $actual[] = array(
+                $token->type,
+                $token->image,
+                $token->startLine,
+                $token->endLine,
+                $token->startColumn,
+                $token->endColumn
+            );
+        }
+
+        $this->assertSame($expected, $actual);
+
+        $list = $this->parseCodeResourceForTest();
+
+        $this->assertInstanceOf('PDepend\\Source\\AST\\ASTArtifactList', $list);
+    }
+
     /**
      * Tests the tokenizer's column calculation implementation.
      *
