@@ -55,3 +55,7 @@ spl_autoload_register(function ($class) {
 });
 
 require_once __DIR__ . '/../../../../vendor/autoload.php';
+
+if (class_exists('PHP_Token')) {
+    require_once __DIR__ . '/load-coverage-tokens.php';
+}
