@@ -1,7 +1,7 @@
 <?php
 class Foo
 {
-    public function bar(int|float|Bar\Biz|null $number)
+    public function bar(array|int|float|Bar\Biz|null $number)
     {
         return $number * 4;
     }
